@@ -1,10 +1,9 @@
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TemplateHaskell #-}
 
 -- |
 -- Module      :  Analyze.Analyze
 -- Description :  Parse sequence file formats and analyze them
--- Copyright   :  (c) Dominik Schrempf 2018
+-- Copyright   :  2021 Dominik Schrempf
 -- License     :  GPL-3.0-or-later
 --
 -- Maintainer  :  dominik.schrempf@gmail.com
@@ -17,19 +16,18 @@ module SLynx.Concatenate.Concatenate
   )
 where
 
-import Control.Monad.Logger
-import Control.Monad.Trans.Reader (ask)
-import qualified ELynx.Data.Sequence.Sequence as S
-import ELynx.Export.Sequence.Fasta
-import ELynx.Tools
+import Control.Monad.Trans.Reader
+import ELynx.Sequence.Export.Fasta
+import qualified ELynx.Sequence.Sequence as S
+import ELynx.Tools.ELynx
+import ELynx.Tools.Environment
 import SLynx.Concatenate.Options
 import SLynx.Tools
 
 -- | Concatenate sequences.
 concatenateCmd :: ELynx ConcatenateArguments ()
 concatenateCmd = do
-  (ConcatenateArguments al fps) <- local <$> ask
-  $(logInfo) "Command: Concatenate sequences."
+  (ConcatenateArguments al fps) <- reader localArguments
   sss <- mapM (readSeqs al) fps
   let result = sequencesToFasta $ S.concatSequences sss
   out "concatenated multi sequence alignment " result ".fasta"
