@@ -3,7 +3,7 @@
 -- |
 -- Module      :  SLynx.Concatenate.Options
 -- Description :  ELynxSeq argument parsing
--- Copyright   :  (c) Dominik Schrempf 2018
+-- Copyright   :  2021 Dominik Schrempf
 -- License     :  GPL-3.0-or-later
 --
 -- Maintainer  :  dominik.schrempf@gmail.com
@@ -18,8 +18,10 @@ module SLynx.Concatenate.Options
 where
 
 import Control.Applicative
-import ELynx.Data.Alphabet.Alphabet
-import ELynx.Tools
+import Data.Aeson
+import ELynx.Alphabet.Alphabet
+import ELynx.Tools.Reproduction
+import GHC.Generics
 import Options.Applicative
 import SLynx.Tools
 
